@@ -107,12 +107,12 @@ class ZafiraClient:
     #     return self.api.send_post(ZafiraClient.TEST_RUNS_PATH, test_run, headers=self.init_auth_headers(),
     #                               default_err_msg="Unable to start test run")
 
-    def start_test_run(self, uuid, name, started_at, framework):
+    def start_test_run(self, uuid, name, started_at, framework, project):
         test_run_v1["uuid"] = uuid
         test_run_v1["name"] = name
         test_run_v1["startedAt"] = started_at
         test_run_v1["framework"] = framework
-        return self.api.send_post(ZafiraClient.TEST_RUNS_PATH_V1, test_run_v1, headers=self.init_auth_headers(),
+        return self.api.send_post(ZafiraClient.TEST_RUNS_PATH_V1.format(project), test_run_v1, headers=self.init_auth_headers(),
                                   default_err_msg="Unable to start test run")
 
 
