@@ -109,11 +109,10 @@ class PyTestZafiraListener(BaseZafiraListener):
             #     # config=self.state.CONFIG
             # ).json()
             # self.state.ci_run_id = self.state.test_run.get('ciRunId')
-            uuid_template = '{}-{}-{}-{}'
             self.state.test_run = self.state.zc.start_test_run(
-                uuid_template.format(str(uuid.uuid4())[0:8], str(uuid.uuid4())[0:7], str(uuid.uuid4())[0:4], str(uuid.uuid4())[0:6]),
+                str(uuid.uuid4()),
                 self.state.suite_name,
-                datetime.datetime.now(),
+                str(datetime.datetime.now()),
                 self.FRAMEWORK,
                 'Test'
             )
